A matrix containing the predictor variables to be used.
y
The vector of numeric responses.
niter
Number of posterior samples.
hsplus
If "hsplus=T" the horseshoe+ extension will be used.
prior
Prior for the individual predictors. If all 1 a standard horseshoe model is fit.
thin
If > 1 thinning is performed to reduce autocorrelation.
restricted
Threshold for restricted Gibbs sampling. In each iteration only coefficients with scale > restricted are updated. Set restricted = 0 for unrestricted Gibbs sampling.
Value
A list containing the posterior samples of the following parameters:
beta
Matrix containing the posterior samples for the regression coefficients.
sigma
Vector contraining the Posterior samples of the error variance.
tau
Vector contraining the Posterior samples of the overall shrinkage.
lambda
Matrix containing the posterior samples for the individual shrinkage parameter.